@@ -122,6 +122,14 @@ class CRUDViews(UserPassesTestMixin, SingleTableView):
                 )
                 return context_data
 
+            def post(self, request, *args, **kwargs):
+                obj = self.get_object()
+                can_edit = list_view_instance.allow_edit_for_record(obj)
+                if not can_edit:
+                    messages.error(request, f'You cannot edit {obj}')
+                    return super().get(request, *args, **kwargs)
+                return super().post(request, *args, **kwargs)
+
         class CRUDDeleteView(ViewCommon, DeleteView):
             template_name = 'django_reusable/crud/delete.pug'
 
@@ -240,14 +248,6 @@ class CRUDViews(UserPassesTestMixin, SingleTableView):
         return kwargs
 
     def _get_edit_link_column(self):
-        # crud = self
-        #
-        # class EditLinkColumn(LinkColumn):
-        #     def render(self, value, record, bound_column):
-        #         if crud.allow_edit_for_record(record):
-        #             return super().render(value, record, bound_column)
-        #         return ''
-
         return LinkColumn(viewname=self.get_edit_url_name(),
                           text=mark_safe('<i class="fa fa-edit"></i>'),
                           args=[A('pk')],
